@@ -1,5 +1,5 @@
 # mssql/base.py
-# Copyright (C) 2005-2021 the SQLAlchemy authors and contributors
+# Copyright (C) 2005-2020 the SQLAlchemy authors and contributors
 # <see AUTHORS file>
 #
 # This module is part of SQLAlchemy and is released under
@@ -9,16 +9,6 @@
     :name: Microsoft SQL Server
 
 
-.. _mssql_external_dialects:
-
-External Dialects
------------------
-
-In addition to the above DBAPI layers with native SQLAlchemy support, there
-are third-party dialects for other DBAPI layers that are compatible
-with SQL Server. See the "External Dialects" list on the
-:ref:`dialect_toplevel` page.
-
 .. _mssql_identity:
 
 Auto Increment Behavior / IDENTITY Columns
@@ -978,7 +968,7 @@ class TIME(sqltypes.TIME):
                     self.__zero_date, value.time()
                 )
             elif isinstance(value, datetime.time):
-                """issue #5339
+                """ issue #5339
                 per: https://github.com/mkleehammer/pyodbc/wiki/Tips-and-Tricks-by-Database-Platform#time-columns
                 pass TIME value as string
                 """  # noqa
@@ -1205,7 +1195,9 @@ class SQL_VARIANT(sqltypes.TypeEngine):
 
 
 class TryCast(sql.elements.Cast):
-    """Represent a SQL Server TRY_CAST expression."""
+    """Represent a SQL Server TRY_CAST expression.
+
+    """
 
     __visit_name__ = "try_cast"
 
@@ -1495,7 +1487,7 @@ class MSExecutionContext(default.DefaultExecutionContext):
                     self.cursor,
                     self._opt_encode(
                         "SET IDENTITY_INSERT %s ON"
-                        % self.identifier_preparer.format_table(tbl)
+                        % self.dialect.identifier_preparer.format_table(tbl)
                     ),
                     (),
                     self,
@@ -1531,7 +1523,7 @@ class MSExecutionContext(default.DefaultExecutionContext):
                 self.cursor,
                 self._opt_encode(
                     "SET IDENTITY_INSERT %s OFF"
-                    % self.identifier_preparer.format_table(
+                    % self.dialect.identifier_preparer.format_table(
                         self.compiled.statement.table
                     )
                 ),
@@ -1548,7 +1540,7 @@ class MSExecutionContext(default.DefaultExecutionContext):
                 self.cursor.execute(
                     self._opt_encode(
                         "SET IDENTITY_INSERT %s OFF"
-                        % self.identifier_preparer.format_table(
+                        % self.dialect.identifier_preparer.format_table(
                             self.compiled.statement.table
                         )
                     )
@@ -2053,6 +2045,14 @@ class MSDDLCompiler(compiler.DDLCompiler):
             ),
         )
 
+        whereclause = index.dialect_options["mssql"]["where"]
+
+        if whereclause is not None:
+            where_compiled = self.sql_compiler.process(
+                whereclause, include_table=False, literal_binds=True
+            )
+            text += " WHERE " + where_compiled
+
         # handle other included columns
         if index.dialect_options["mssql"]["include"]:
             inclusions = [
@@ -2066,14 +2066,6 @@ class MSDDLCompiler(compiler.DDLCompiler):
                 [preparer.quote(c.name) for c in inclusions]
             )
 
-        whereclause = index.dialect_options["mssql"]["where"]
-
-        if whereclause is not None:
-            where_compiled = self.sql_compiler.process(
-                whereclause, include_table=False, literal_binds=True
-            )
-            text += " WHERE " + where_compiled
-
         return text
 
     def visit_drop_index(self, drop):
@@ -2750,7 +2742,7 @@ class MSDialect(default.DefaultDialect):
         # We also run an sp_columns to check for identity columns:
         cursor = connection.execute(
             sql.text(
-                "EXEC sp_columns @table_name = :table_name, "
+                "sp_columns @table_name = :table_name, "
                 "@table_owner = :table_owner",
             ),
             {"table_name": tablename, "table_owner": owner},
@@ -2806,7 +2798,7 @@ class MSDialect(default.DefaultDialect):
                 C.c.table_name == tablename,
                 C.c.table_schema == owner,
             ),
-        ).order_by(TC.c.constraint_name, C.c.ordinal_position)
+        )
         c = connection.execute(s)
         constraint_name = None
         for row in c:
